'use client'

import React, { useState, useEffect } from 'react'
import { motion, useAnimation, AnimatePresence } from 'framer-motion'
import { useInView } from 'react-intersection-observer'

interface TestimonialProps {
  quote: string
  author: string
  source: string
}

const testimonials: TestimonialProps[] = [
  {
    quote: "Intuitive design happens when current knowledge is the same as the target knowledge.",
    author: "Jared Spool",
    source: "Web Site Usability: A Designer's Guide"
  },
  {
    quote: "Good design is actually a lot harder to notice than poor design, in part because good designs fit our needs so well that the design is invisible.",
    author: "Don Norman",
    source: "The Design of Everyday Things"
  },
  {
    quote: "A user interface is like a joke. If you have to explain it, it's not that good.",
    author: "Martin LeBlanc",
    source: "Iconfinder"
  }
]

const TestimonialSection: React.FC = () => {
  const [currentIndex, setCurrentIndex] = useState(0)
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  useEffect(() => {
    const timer = setInterval(() => {
      setCurrentIndex((prevIndex) => (prevIndex + 1) % testimonials.length)
    }, 5000) // Change testimonial every 5 seconds

    return () => clearInterval(timer)
  }, [])

  const containerVariants = {
    hidden: { opacity: 0, y: 50 },
    visible: {
      opacity: 1,
      y: 0,
      transition: {
        duration: 0.5
      }
    }
  }

  const slideVariants = {
    enter: { opacity: 0, x: 50 },
    center: { opacity: 1, x: 0 },
    exit: { opacity: 0, x: -50 }
  }

  const highlightWords = (text: string) => {
    return text.split(' ').map((word, index) => {
      const shouldHighlight = ['Intuitive', 'design', 'happens', 'when', 'is', 'the', 'same', 'as', 'the'].includes(word)
      return (
        <span key={index} className={shouldHighlight ? 'tsts-highlight' : ''}>
          {word}{' '}
        </span>
      )
    })
  }

  return (
    <section ref={ref} className="tsts-section bg-gray-800 py-16 px-4">
      <div className="tsts-container max-w-4xl mx-auto">
        <motion.div
          className="tsts-testimonial-wrapper bg-gray-700 rounded-lg p-8 shadow-lg"
          variants={containerVariants}
          initial="hidden"
          animate={controls}
          whileHover={{ scale: 1.05 }}
          transition={{ duration: 0.3 }}
        >
          <AnimatePresence mode="wait">
            <motion.div
              key={currentIndex}
              className="tsts-testimonial"
              variants={slideVariants}
              initial="enter"
              animate="center"
              exit="exit"
              transition={{ duration: 0.5 }}
            >
              <p className="tsts-quote text-2xl mb-4 text-white">
                {highlightWords(testimonials[currentIndex].quote)}
              </p>
              <div className="tsts-author-info">
                <p className="tsts-author text-lg font-semibold text-white">
                  —{testimonials[currentIndex].author}
                </p>
                <p className="tsts-source text-sm text-gray-400">
                  {testimonials[currentIndex].source}
                </p>
              </div>
            </motion.div>
          </AnimatePresence>
        </motion.div>
      </div>
    </section>
  )
}

export default TestimonialSection